@@ -1,11 +1,11 @@
 // This file replaces `index.js` in bundlers like webpack or Rollup,
 // according to `browser` config in `package.json`.
 
-let { urlAlphabet } = require('./url-alphabet')
+export { urlAlphabet } from './url-alphabet/index.js'
 
-let random = bytes => crypto.getRandomValues(new Uint8Array(bytes))
+export let random = bytes => crypto.getRandomValues(new Uint8Array(bytes))
 
-let customRandom = (alphabet, defaultSize, getRandom) => {
+export let customRandom = (alphabet, defaultSize, getRandom) => {
   // First, a bitmask is necessary to generate the ID. The bitmask makes bytes
   // values closer to the alphabet size. The bitmask calculates the closest
   // `2^31 - 1` number, which exceeds the alphabet size.
@@ -44,34 +44,28 @@ let customRandom = (alphabet, defaultSize, getRandom) => {
   }
 }
 
-let customAlphabet = (alphabet, size = 21) =>
+export let customAlphabet = (alphabet, size = 21) =>
   customRandom(alphabet, size, random)
 
-let nanoid = (size = 21) => {
-  let id = ''
-  let bytes = crypto.getRandomValues(new Uint8Array(size))
-
-  // A compact alternative for `for (var i = 0; i < step; i++)`.
-  while (size--) {
+export let nanoid = (size = 21) =>
+  crypto.getRandomValues(new Uint8Array(size)).reduce((id, byte) => {
     // It is incorrect to use bytes exceeding the alphabet size.
     // The following mask reduces the random byte in the 0-255 value
     // range to the 0-63 value range. Therefore, adding hacks, such
     // as empty string fallback or magic numbers, is unneccessary because
     // the bitmask trims bytes down to the alphabet size.
-    let byte = bytes[size] & 63
+    byte &= 63
     if (byte < 36) {
       // `0-9a-z`
       id += byte.toString(36)
     } else if (byte < 62) {
       // `A-Z`
       id += (byte - 26).toString(36).toUpperCase()
-    } else if (byte < 63) {
-      id += '_'
-    } else {
+    } else if (byte > 62) {
       id += '-'
+    } else {
+      id += '_'
     }
-  }
-  return id
-}
+    return id
+  }, '')
 
-module.exports = { nanoid, customAlphabet, customRandom, urlAlphabet, random }
