@@ -1,21 +1,25 @@
 #!/usr/bin/env node
 
-let { uid: uidSecure } = require('uid/secure')
-let { v4: lukeed4 } = require('@lukeed/uuid')
-let { v4: uuid4 } = require('uuid')
-let benchmark = require('benchmark')
-let shortid = require('shortid')
-let uidSafe = require('uid-safe')
-let { uid } = require('uid')
-let crypto = require('crypto')
-let pico = require('picocolors')
-let cuid = require('cuid')
-let rndm = require('rndm')
-let srs = require('secure-random-string')
+import { uid as uidSecure } from 'uid/secure'
+import { v4 as lukeed4 } from '@lukeed/uuid'
+import { v4 as napiV4 } from '@napi-rs/uuid'
+import { v4 as uuid4 } from 'uuid'
+import benchmark from 'benchmark'
+import shortid from 'shortid'
+import uidSafe from 'uid-safe'
+import { uid } from 'uid'
+import crypto from 'crypto'
+import pico from 'picocolors'
+import cuid from 'cuid'
+import rndm from 'rndm'
+import srs from 'secure-random-string'
 
-let { nanoid: aNanoid, customAlphabet: aCustomAlphabet } = require('../async')
-let { nanoid, customAlphabet } = require('../')
-let { nanoid: nonSecure } = require('../non-secure')
+import {
+  customAlphabet as aCustomAlphabet,
+  nanoid as aNanoid
+} from '../async/index.js'
+import { nanoid, customAlphabet } from '../index.js'
+import { nanoid as nonSecure } from '../non-secure/index.js'
 
 let suite = new benchmark.Suite()
 
@@ -32,6 +36,9 @@ suite
   .add('crypto.randomUUID', () => {
     crypto.randomUUID()
   })
+  .add('@napi-rs/uuid', () => {
+    napiV4()
+  })
   .add('uid/secure', () => {
     uidSecure(32)
   })
